<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja" sourcelanguage="en">
<context>
    <name>Alert</name>
    <message>
        <location filename="../src/alert.cpp" line="236"/>
        <source>Close (%1)</source>
        <translation>閉じる (%1)</translation>
    </message>
    <message>
        <location filename="../src/alert.cpp" line="177"/>
        <source>Collapse</source>
        <translation>セッション (&amp;S)</translation>
    </message>
    <message>
        <location filename="../src/alert.cpp" line="181"/>
        <source>Expand</source>
        <translation>詳細</translation>
    </message>
</context>
<context>
    <name>AlertLayer</name>
    <message>
        <location filename="../src/alert_layer.cpp" line="37"/>
        <source>Dismiss Alert</source>
        <translation>警告を無視する</translation>
    </message>
    <message>
        <location filename="../src/alert_layer.cpp" line="38"/>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
</context>
<context>
    <name>DailyProgress</name>
    <message numerus="yes">
        <location filename="../src/daily_progress.cpp" line="503"/>
        <source>%1% of %Ln minute(s)</source>
        <translation>
            <numerusform>全 %Ln 分中 %1%</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/daily_progress.cpp" line="505"/>
        <source>%1% of %Ln word(s)</source>
        <translation>
            <numerusform>全 %Ln 単語中 %1%</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/daily_progress.cpp" line="507"/>
        <source>%Ln word(s)</source>
        <translation>
            <numerusform>全 %Ln 単語</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/daily_progress.cpp" line="509"/>
        <source>%Ln minute(s)</source>
        <translation>
            <numerusform>全 %Ln 分</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../src/daily_progress.cpp" line="511"/>
        <source>0%</source>
        <translation>0%</translation>
    </message>
</context>
<context>
    <name>DailyProgressDialog</name>
    <message>
        <location filename="../src/daily_progress_dialog.cpp" line="146"/>
        <source>Daily Progress</source>
        <translation>日毎の進捗</translation>
    </message>
    <message>
        <location filename="../src/daily_progress_dialog.cpp" line="282"/>
        <source>Longest streak</source>
        <translation>最長連続執筆期間</translation>
    </message>
    <message>
        <location filename="../src/daily_progress_dialog.cpp" line="285"/>
        <source>Current streak</source>
        <translation>現在の連続執筆期間</translation>
    </message>
    <message>
        <location filename="../src/daily_progress_dialog.cpp" line="298"/>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/daily_progress_dialog.cpp" line="303"/>
        <source>%n day(s)</source>
        <translation>
            <numerusform>%n 日</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../src/daily_progress_dialog.cpp" line="304"/>
        <source>%1 &amp;ndash; %2</source>
        <translation>%1 &amp;ndash; %2</translation>
    </message>
</context>
<context>
    <name>DailyProgressLabel</name>
    <message>
        <location filename="../src/daily_progress_label.cpp" line="30"/>
        <location filename="../src/daily_progress_label.cpp" line="47"/>
        <source>%1% of daily goal</source>
        <translation>一日の目標の %1%</translation>
    </message>
</context>
<context>
    <name>DictionaryDialog</name>
    <message>
        <location filename="../src/spelling/dictionary_dialog.cpp" line="36"/>
        <source>Set Language</source>
        <translation>言語の変更</translation>
    </message>
</context>
<context>
    <name>Document</name>
    <message>
        <location filename="../src/document.cpp" line="425"/>
        <source>(Untitled %1)</source>
        <translation>(無題 %1)</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="428"/>
        <source>%1 (Read-Only)</source>
        <translation>%1 (読み込み専用)</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="492"/>
        <location filename="../src/document.cpp" line="517"/>
        <location filename="../src/document.cpp" line="553"/>
        <location filename="../src/document.cpp" line="559"/>
        <source>Sorry</source>
        <translation>エラー</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="492"/>
        <source>Unable to save &apos;%1&apos;.</source>
        <translation>&apos;%1&apos; を保存できませんでした。</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="507"/>
        <source>Save File As</source>
        <translation>名前を付けて保存</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="517"/>
        <location filename="../src/document.cpp" line="553"/>
        <source>Unable to overwrite &apos;%1&apos;.</source>
        <translation>&apos;%1&apos; を上書きすることができませんでした。</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="546"/>
        <source>Rename File</source>
        <translation>ファイル名の変更</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="559"/>
        <source>Unable to rename &apos;%1&apos;.</source>
        <translation>&apos;%1&apos; の名前を変更できませんでした。</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="585"/>
        <source>Reload File?</source>
        <translation>ファイルを再読み込みしますか？</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="586"/>
        <source>Reload the file &apos;%1&apos; from disk?</source>
        <translation>ファイル %1 を再読み込みしますか？</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="587"/>
        <source>All unsaved changes will be lost.</source>
        <translation>保存されていない変更はすべて失われます。</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="589"/>
        <source>Reload</source>
        <translation>再読み込み</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="1321"/>
        <source>Untitled %1</source>
        <translation>無題 %1</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="1375"/>
        <source>Question</source>
        <translation>問い合わせ</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="1376"/>
        <source>Saving as plain text will discard all formatting. Discard formatting?</source>
        <translation>プレーン・テキストとして保存した場合、すべての書式が失われます。よろしいですか？</translation>
    </message>
</context>
<context>
    <name>DocumentWatcher</name>
    <message>
        <location filename="../src/document_watcher.cpp" line="191"/>
        <source>File Changed</source>
        <translation>ファイルが変更されています</translation>
    </message>
    <message>
        <location filename="../src/document_watcher.cpp" line="192"/>
        <source>The file &apos;%1&apos; was changed by another program.</source>
        <translation>他のプログラムによりファイル %1 は変更されています。</translation>
    </message>
    <message>
        <location filename="../src/document_watcher.cpp" line="193"/>
        <source>Do you want to reload the file?</source>
        <translation>ファイルを読み込み直しますか？</translation>
    </message>
    <message>
        <location filename="../src/document_watcher.cpp" line="195"/>
        <source>Reload</source>
        <translation>再読み込み</translation>
    </message>
    <message>
        <location filename="../src/document_watcher.cpp" line="200"/>
        <source>Ignore</source>
        <translation>無視</translation>
    </message>
    <message>
        <location filename="../src/document_watcher.cpp" line="211"/>
        <source>File Deleted</source>
        <translation>ファイルが削除されました</translation>
    </message>
    <message>
        <location filename="../src/document_watcher.cpp" line="212"/>
        <source>The file %1 was deleted by another program.</source>
        <translation>他のプログラムによりファイル %1 は削除されました。</translation>
    </message>
    <message>
        <location filename="../src/document_watcher.cpp" line="213"/>
        <source>Do you want to save or close the file?</source>
        <translation>ファイルを保存、または閉じますか？</translation>
    </message>
</context>
<context>
    <name>DocxReader</name>
    <message>
        <location filename="../src/fileformats/docx_reader.cpp" line="94"/>
        <source>Unable to open archive.</source>
        <translation>アーカイブを開けませんでした。</translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <location filename="../src/find_dialog.cpp" line="47"/>
        <source>Search for:</source>
        <translation>検索する文字列:</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="49"/>
        <source>Replace with:</source>
        <translation>置換後の文字列:</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="53"/>
        <source>Ignore case</source>
        <translation>大文字と小文字を区別しない</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="54"/>
        <source>Whole words only</source>
        <translation>単語単位で探す</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="55"/>
        <source>Regular expressions</source>
        <translation>正規表現</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="58"/>
        <source>Search up</source>
        <translation>前を検索</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="59"/>
        <source>Search down</source>
        <translation>次を検索</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="66"/>
        <source>&amp;Find</source>
        <translation>検索 (&amp;F)</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="70"/>
        <source>&amp;Replace</source>
        <translation>置換 (&amp;R)</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="74"/>
        <source>Replace &amp;All</source>
        <translation>すべて置換 (&amp;A)</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="151"/>
        <source>Find</source>
        <translation>検索</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="159"/>
        <source>Replace</source>
        <translation>置換</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/find_dialog.cpp" line="275"/>
        <source>Replace %n instance(s)?</source>
        <translation>
            <numerusform>%n 件置換しますか？</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="275"/>
        <source>Question</source>
        <translation>確認</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="279"/>
        <location filename="../src/find_dialog.cpp" line="354"/>
        <source>Sorry</source>
        <translation>エラー</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="279"/>
        <location filename="../src/find_dialog.cpp" line="354"/>
        <source>Phrase not found.</source>
        <translation>見つかりませんでした。</translation>
    </message>
</context>
<context>
    <name>FormatManager</name>
    <message>
        <location filename="../src/fileformats/format_manager.cpp" line="71"/>
        <source>OpenDocument Text</source>
        <translation>OpenDocument 文書</translation>
    </message>
    <message>
        <location filename="../src/fileformats/format_manager.cpp" line="73"/>
        <source>Office Open XML</source>
        <translation>Office Open XML</translation>
    </message>
    <message>
        <location filename="../src/fileformats/format_manager.cpp" line="75"/>
        <source>Rich Text Format</source>
        <translation>リッチ テキスト形式</translation>
    </message>
    <message>
        <location filename="../src/fileformats/format_manager.cpp" line="77"/>
        <source>Plain Text</source>
        <translation>テキスト文書</translation>
    </message>
    <message>
        <location filename="../src/fileformats/format_manager.cpp" line="92"/>
        <source>All Files</source>
        <translation>すべてのファイル</translation>
    </message>
    <message>
        <location filename="../src/fileformats/format_manager.cpp" line="106"/>
        <source>All Supported Files</source>
        <translation>サポートされているすべてのファイル</translation>
    </message>
</context>
<context>
    <name>Highlighter</name>
    <message>
        <location filename="../src/spelling/highlighter.cpp" line="54"/>
        <source>Add</source>
        <translation>追加</translation>
    </message>
    <message>
        <location filename="../src/spelling/highlighter.cpp" line="55"/>
        <source>Check Spelling...</source>
        <translation>スペルチェック...</translation>
    </message>
    <message>
        <location filename="../src/spelling/highlighter.cpp" line="129"/>
        <source>(No suggestions found)</source>
        <translation>(修正候補は見つかりませんでした)</translation>
    </message>
</context>
<context>
    <name>ImageButton</name>
    <message>
        <location filename="../src/image_button.cpp" line="100"/>
        <source>Open Image</source>
        <translation>画像の選択</translation>
    </message>
    <message>
        <location filename="../src/image_button.cpp" line="100"/>
        <source>Images(%1)</source>
        <translation>画像 (%1)</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <location filename="../src/locale_dialog.cpp" line="51"/>
        <source>Select application language:</source>
        <translation>言語の選択:</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="54"/>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;システムの言語&gt;</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="189"/>
        <source>Note</source>
        <translation>注意</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="189"/>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>言語の変更を反映させるためにアプリケーションを再起動してください。</translation>
    </message>
</context>
<context>
    <name>OdtReader</name>
    <message>
        <location filename="../src/fileformats/odt_reader.cpp" line="68"/>
        <source>Unable to open archive.</source>
        <translation>アーカイブを開けませんでした。</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="109"/>
        <source>Preferences</source>
        <translation>設定</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="112"/>
        <source>General</source>
        <translation>一般</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="114"/>
        <source>Statistics</source>
        <translation>統計</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="116"/>
        <source>Toolbar</source>
        <translation>ツール バー</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="115"/>
        <source>Spell Checking</source>
        <translation>スペルチェック</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="453"/>
        <source>Select Dictionary</source>
        <translation>辞書の選択</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="467"/>
        <location filename="../src/preferences_dialog.cpp" line="570"/>
        <source>Sorry</source>
        <translation>エラー</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="467"/>
        <source>Unable to open archive.</source>
        <translation>アーカイブを開けませんでした。</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="570"/>
        <source>The archive does not contain a usable dictionary.</source>
        <translation>このアーカイブには有効な辞書が含まれていません。</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="256"/>
        <location filename="../src/preferences_dialog.cpp" line="395"/>
        <location filename="../src/preferences_dialog.cpp" line="558"/>
        <source>Question</source>
        <translation>確認</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="117"/>
        <source>Shortcuts</source>
        <translation>ショートカット一覧</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="257"/>
        <source>One or more shortcuts conflict. Do you wish to proceed?</source>
        <translation>ショートカットがいくつかバッティングしています。続行してもよろしいですか？</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="558"/>
        <source>The dictionary &quot;%1&quot; already exists. Do you want to replace it?</source>
        <translation>&quot;%1&quot; という名前の辞書は既にあります。置き換えても良いですか？</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="113"/>
        <source>Daily Goal</source>
        <translation>一日の目標</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="793"/>
        <source>None</source>
        <translation>なし</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="795"/>
        <source>Minutes:</source>
        <translation>分:</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="802"/>
        <location filename="../src/preferences_dialog.cpp" line="912"/>
        <source>Words:</source>
        <translation>語:</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="705"/>
        <source>Editing</source>
        <translation>編集</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="707"/>
        <source>Always vertically center</source>
        <translation>カーソル位置を常に縦方向の中央にする</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="708"/>
        <source>Block insertion cursor</source>
        <translation>挿入モードでもブロック形のカーソルを使う</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="709"/>
        <source>Smooth fonts</source>
        <translation>フォントをなめらかにする</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="710"/>
        <source>Typewriter sounds</source>
        <translation>タイプライター音を再生する</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="712"/>
        <source>Smart quotes:</source>
        <translation>スマート引用符:</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="719"/>
        <source>Double</source>
        <translation>二重</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="720"/>
        <source>Single</source>
        <translation>一重</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="741"/>
        <source>Scenes</source>
        <translation>シーン一覧</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="748"/>
        <source>Divider:</source>
        <translation>ディバイダー:</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="751"/>
        <source>Saving</source>
        <translation>保存</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="753"/>
        <source>Automatically save changes</source>
        <translation>変更を自動的に保存する</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="754"/>
        <source>Remember cursor position</source>
        <translation>カーソル位置を記憶する</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="872"/>
        <source>Word count</source>
        <translation>単語数</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="873"/>
        <source>Page count</source>
        <translation>ページ数</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="874"/>
        <source>Paragraph count</source>
        <translation>段落数</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="875"/>
        <source>Character count</source>
        <translation>文字数</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="898"/>
        <source>Characters:</source>
        <translation>文字</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="905"/>
        <source>Paragraphs:</source>
        <translation>段落</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="884"/>
        <source>Word Count Algorithm</source>
        <translation>単語数カウント・アルゴリズム</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="396"/>
        <source>Reset daily progress for today to zero?</source>
        <translation>今日の進捗状況を0にリセットしますか？</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="755"/>
        <source>Write byte order mark in plain text files</source>
        <translation>プレーンテキストにも BOM を追加する</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="757"/>
        <source>Default format:</source>
        <translation>デフォルトの形式:</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="818"/>
        <source>Reset Today</source>
        <translation>本日分をリセット</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="831"/>
        <source>History</source>
        <translation>履歴</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="833"/>
        <source>Remember history</source>
        <translation>履歴を保存する</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="836"/>
        <source>Show streaks</source>
        <translation>連続執筆期間の表示</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="851"/>
        <source>Minimum progress for streaks:</source>
        <translation>連続執筆期間の最小値:</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="886"/>
        <source>Detect word boundaries</source>
        <translation>単語の境界を認識する</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="887"/>
        <source>Divide character count by six</source>
        <translation>文字数を 6 で割る</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="888"/>
        <source>Count each letter as a word</source>
        <translation>一文字ごとに単語として数える</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="896"/>
        <source>Page Count Algorithm</source>
        <translation>ページ数カウント・アルゴリズム</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1039"/>
        <source>Style</source>
        <translation>スタイル</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1042"/>
        <source>Icons Only</source>
        <translation>アイコンのみ</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1043"/>
        <source>Text Only</source>
        <translation>文字のみ</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1044"/>
        <source>Text Alongside Icons</source>
        <translation>アイコンの横に文字</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1045"/>
        <source>Text Under Icons</source>
        <translation>アイコンの下に文字</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1049"/>
        <source>Text Position:</source>
        <translation>文字の位置:</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1052"/>
        <source>Actions</source>
        <translation>アクション</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1068"/>
        <source>Move Up</source>
        <translation>上へ移動</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1070"/>
        <source>Move Down</source>
        <translation>下へ移動</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1072"/>
        <source>Add Separator</source>
        <translation>セパレーターを追加</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1106"/>
        <source>Command</source>
        <translation>コマンド</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1106"/>
        <source>Shortcut</source>
        <translation>ショートカット</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1106"/>
        <source>Action</source>
        <translation>アクション</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="959"/>
        <source>Check spelling as you type</source>
        <translation>タイプするごとにチェックする</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="960"/>
        <source>Ignore words in UPPERCASE</source>
        <translation>大文字を無視する</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="961"/>
        <source>Ignore words with numbers</source>
        <translation>数字が含まれる単語を無視する</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="974"/>
        <source>Language</source>
        <translation>言語</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="978"/>
        <location filename="../src/preferences_dialog.cpp" line="999"/>
        <source>Add</source>
        <translation>追加</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1011"/>
        <source>Remove</source>
        <translation>削除</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="994"/>
        <source>Personal Dictionary</source>
        <translation>ユーザー辞書</translation>
    </message>
</context>
<context>
    <name>RtfReader</name>
    <message>
        <location filename="../src/fileformats/rtf_reader.cpp" line="209"/>
        <location filename="../src/fileformats/rtf_reader.cpp" line="213"/>
        <source>Not a supported RTF file.</source>
        <translation>サポートしていないリッチ テキスト形式です。</translation>
    </message>
</context>
<context>
    <name>RtfTokenizer</name>
    <message>
        <location filename="../src/fileformats/rtf_tokenizer.cpp" line="151"/>
        <source>Unexpectedly reached end of file.</source>
        <translation>ファイルの最後に到達しました。</translation>
    </message>
</context>
<context>
    <name>SceneList</name>
    <message>
        <location filename="../src/scene_list.cpp" line="89"/>
        <source>Ctrl+Shift+Down</source>
        <translation>Ctrl+Shift+Down</translation>
    </message>
    <message>
        <location filename="../src/scene_list.cpp" line="94"/>
        <source>Move Scenes Up</source>
        <translation>シーンをひとつ上に移動</translation>
    </message>
    <message>
        <location filename="../src/scene_list.cpp" line="95"/>
        <source>Ctrl+Shift+Up</source>
        <translation>Ctrl+Shift+Up</translation>
    </message>
    <message>
        <location filename="../src/scene_list.cpp" line="115"/>
        <source>Toggle Scene List</source>
        <translation>シーン・リストの表示の切り替え</translation>
    </message>
    <message>
        <location filename="../src/scene_list.cpp" line="116"/>
        <source>Shift+F4</source>
        <translation>Shift+F4</translation>
    </message>
    <message>
        <location filename="../src/scene_list.cpp" line="399"/>
        <source>Show scene list (%1)</source>
        <translation>シーン・リストの表示 (%1)</translation>
    </message>
    <message>
        <location filename="../src/scene_list.cpp" line="400"/>
        <source>Hide scene list (%1)</source>
        <translation>シーン・リストの非表示 (%1)</translation>
    </message>
    <message>
        <location filename="../src/scene_list.cpp" line="147"/>
        <source>Filter</source>
        <translation>絞込み</translation>
    </message>
    <message>
        <location filename="../src/scene_list.cpp" line="88"/>
        <source>Move Scenes Down</source>
        <translation>シーンをひとつ下に移動</translation>
    </message>
    <message>
        <location filename="../src/scene_list.cpp" line="155"/>
        <source>Resize scene list</source>
        <translation>シーン・リストのリサイズ</translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message>
        <location filename="../src/session.cpp" line="43"/>
        <location filename="../src/session_manager.cpp" line="57"/>
        <location filename="../src/session_manager.cpp" line="428"/>
        <location filename="../src/session_manager.cpp" line="451"/>
        <location filename="../src/session_manager.cpp" line="460"/>
        <location filename="../src/session_manager.cpp" line="461"/>
        <source>Default</source>
        <translation>デフォルト</translation>
    </message>
</context>
<context>
    <name>SessionManager</name>
    <message>
        <location filename="../src/session_manager.cpp" line="52"/>
        <source>Manage Sessions</source>
        <translation>セッションの管理</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="83"/>
        <source>S&amp;essions</source>
        <translation>セッション (&amp;S)</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="97"/>
        <source>New</source>
        <translation>新規</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="100"/>
        <source>Duplicate</source>
        <translation>複製</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="103"/>
        <source>Rename</source>
        <translation>名前の変更</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="106"/>
        <source>Delete</source>
        <translation>削除</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="109"/>
        <source>Switch To</source>
        <translation>切り替え</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="220"/>
        <source>New Session</source>
        <translation>新しいセッション</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="279"/>
        <source>Duplicate Session</source>
        <translation>セッションの複製</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="324"/>
        <source>Rename Session</source>
        <translation>セッション名の変更</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="351"/>
        <source>Question</source>
        <translation>確認</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="351"/>
        <source>Delete selected session?</source>
        <translation>選択中のセッションを削除しますか？</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="423"/>
        <source>Session name:</source>
        <translation>セッション名:</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="431"/>
        <source>Sorry</source>
        <translation>エラー</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="431"/>
        <source>The requested session name is already in use.</source>
        <translation>指定したセッション名は既にあります。</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="487"/>
        <source>&amp;New...</source>
        <translation>新規 (&amp;N)...</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="487"/>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="488"/>
        <source>&amp;Manage...</source>
        <translation>管理 (&amp;M)...</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="488"/>
        <source>Ctrl+Shift+M</source>
        <translation>Ctrl+Shift+M</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <location filename="../src/shortcut_edit.cpp" line="126"/>
        <source>Clear</source>
        <translation>消去</translation>
    </message>
    <message>
        <location filename="../src/shortcut_edit.cpp" line="129"/>
        <source>Reset to Default</source>
        <translation>デフォルトに戻す</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1149"/>
        <location filename="../src/symbols_dialog.cpp" line="219"/>
        <source>Shortcut:</source>
        <translation>ショートカット:</translation>
    </message>
</context>
<context>
    <name>SmartQuote</name>
    <message>
        <location filename="../src/smart_quotes.cpp" line="150"/>
        <source>Replacing quotation marks...</source>
        <translation>引用符の置換...</translation>
    </message>
    <message>
        <location filename="../src/smart_quotes.cpp" line="151"/>
        <source>Please Wait</source>
        <translation>お待ちください</translation>
    </message>
</context>
<context>
    <name>SpellChecker</name>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="134"/>
        <source>Check Spelling</source>
        <translation>スペルチェック</translation>
    </message>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="142"/>
        <source>&amp;Add</source>
        <translation>追加 (&amp;A)</translation>
    </message>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="145"/>
        <source>&amp;Ignore</source>
        <translation>無視 (&amp;I)</translation>
    </message>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="148"/>
        <source>I&amp;gnore All</source>
        <translation>すべて無視 (&amp;G)</translation>
    </message>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="153"/>
        <source>&amp;Change</source>
        <translation>変更 (&amp;C)</translation>
    </message>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="156"/>
        <source>C&amp;hange All</source>
        <translation>すべて変更 (&amp;H)</translation>
    </message>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="171"/>
        <source>Not in dictionary:</source>
        <translation>辞書にないもの:</translation>
    </message>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="179"/>
        <source>Change to:</source>
        <translation>変更後:</translation>
    </message>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="195"/>
        <source>Checking spelling...</source>
        <translation>スペルチェック中です...</translation>
    </message>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="195"/>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="196"/>
        <source>Please wait</source>
        <translation>お待ちください</translation>
    </message>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="223"/>
        <source>Continue checking at beginning of file?</source>
        <translation>ファイルの先頭からチェックを続けますか？</translation>
    </message>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="282"/>
        <source>Spell check complete.</source>
        <translation>スペルチェックが終わりました。</translation>
    </message>
</context>
<context>
    <name>SymbolsDialog</name>
    <message>
        <location filename="../src/symbols_dialog.cpp" line="96"/>
        <source>Symbols</source>
        <translation>シンボル一覧</translation>
    </message>
    <message>
        <location filename="../src/symbols_dialog.cpp" line="103"/>
        <source>Recently used symbols</source>
        <translation>最近使ったシンボル</translation>
    </message>
    <message>
        <location filename="../src/symbols_dialog.cpp" line="133"/>
        <source>All symbols</source>
        <translation>すべてのシンボル</translation>
    </message>
    <message>
        <location filename="../src/symbols_dialog.cpp" line="195"/>
        <source>Details</source>
        <translation>詳細</translation>
    </message>
    <message>
        <location filename="../src/symbols_dialog.cpp" line="221"/>
        <source>Name:</source>
        <translation>名前:</translation>
    </message>
    <message>
        <location filename="../src/symbols_dialog.cpp" line="231"/>
        <source>Insert</source>
        <translation>挿入</translation>
    </message>
</context>
<context>
    <name>SymbolsModel</name>
    <message>
        <location filename="../src/symbols_model.cpp" line="107"/>
        <source>Blocks</source>
        <translation>ブロック</translation>
    </message>
    <message>
        <location filename="../src/symbols_model.cpp" line="107"/>
        <source>Scripts</source>
        <translation>スクリプト</translation>
    </message>
</context>
<context>
    <name>Theme</name>
    <message>
        <location filename="../src/theme.cpp" line="103"/>
        <source>Untitled %1</source>
        <translation>無題 %1</translation>
    </message>
</context>
<context>
    <name>ThemeDialog</name>
    <message>
        <location filename="../src/theme_dialog.cpp" line="103"/>
        <source>Name:</source>
        <translation>名前:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="164"/>
        <source>No Image</source>
        <translation>イメージなし</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="164"/>
        <source>Tiled</source>
        <translation>並べて表示</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="164"/>
        <location filename="../src/theme_dialog.cpp" line="196"/>
        <source>Centered</source>
        <translation>中央に表示</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="164"/>
        <location filename="../src/theme_dialog.cpp" line="196"/>
        <source>Stretched</source>
        <translation>画面に合わせて伸縮</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="164"/>
        <source>Scaled</source>
        <translation>ページ縦幅に合わせる</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="164"/>
        <source>Zoomed</source>
        <translation>ページ横幅に合わせる</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="211"/>
        <source>Opacity:</source>
        <translation>不透明度:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="212"/>
        <source>Position:</source>
        <translation>位置:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="213"/>
        <source>Width:</source>
        <translation>幅:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="217"/>
        <source>Round Text Background Corners</source>
        <translation>テキスト背景の角を丸める</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="231"/>
        <location filename="../src/theme_dialog.cpp" line="249"/>
        <location filename="../src/theme_dialog.cpp" line="279"/>
        <source>Radius:</source>
        <translation>半径:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="235"/>
        <source>Blur Text Background</source>
        <translation>テキスト背景をぼやかす:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="253"/>
        <source>Text Background Drop Shadow</source>
        <translation>テキスト背景の影</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="280"/>
        <source>Vertical Offset:</source>
        <translation>垂直方向の距離:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="284"/>
        <source>Margins</source>
        <translation>マージン</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="302"/>
        <source>Window:</source>
        <translation>ウィンドウ:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="303"/>
        <source>Page:</source>
        <translation>ページ:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="361"/>
        <source>Indent first line</source>
        <translation>最初の行をインデントする</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="368"/>
        <source>Above:</source>
        <translation>上に:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="369"/>
        <source>Below:</source>
        <translation>下に:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="160"/>
        <source>Remove</source>
        <translation>削除</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="93"/>
        <source>Edit Theme</source>
        <translation>テーマを編集</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="150"/>
        <source>Window Background</source>
        <translation>ウィンドウの背景</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="178"/>
        <location filename="../src/theme_dialog.cpp" line="332"/>
        <source>Type:</source>
        <translation>画像の配置:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="144"/>
        <location filename="../src/theme_dialog.cpp" line="176"/>
        <location filename="../src/theme_dialog.cpp" line="210"/>
        <location filename="../src/theme_dialog.cpp" line="278"/>
        <source>Color:</source>
        <translation>背景色:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="177"/>
        <source>Image:</source>
        <translation>画像:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="202"/>
        <location filename="../src/theme_dialog.cpp" line="224"/>
        <location filename="../src/theme_dialog.cpp" line="242"/>
        <location filename="../src/theme_dialog.cpp" line="264"/>
        <location filename="../src/theme_dialog.cpp" line="271"/>
        <location filename="../src/theme_dialog.cpp" line="288"/>
        <location filename="../src/theme_dialog.cpp" line="295"/>
        <location filename="../src/theme_dialog.cpp" line="344"/>
        <location filename="../src/theme_dialog.cpp" line="350"/>
        <location filename="../src/theme_dialog.cpp" line="356"/>
        <source> pixels</source>
        <translation> ピクセル</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="196"/>
        <source>Left</source>
        <translation>左寄せ</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="182"/>
        <source>Text Background</source>
        <translation>テキスト背景</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="196"/>
        <source>Right</source>
        <translation>右寄せ</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="116"/>
        <source>Text</source>
        <translation>文字</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="145"/>
        <source>Font:</source>
        <translation>フォント:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="146"/>
        <source>Misspelled:</source>
        <translation>スペルミス:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="307"/>
        <source>Line Spacing</source>
        <translation>行間のスペース</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="311"/>
        <source>Single</source>
        <translation>シングル</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="311"/>
        <source>1.5 Lines</source>
        <translation>1.5倍</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="311"/>
        <source>Double</source>
        <translation>2倍</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="311"/>
        <source>Proportional</source>
        <translation>プロポーショナル</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="333"/>
        <source>Height:</source>
        <translation>高さ:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="341"/>
        <source>Paragraph Spacing</source>
        <translation>段落間のマージン</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="367"/>
        <source>Tab Width:</source>
        <translation>タブ幅:</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="253"/>
        <source>New Theme</source>
        <translation>新しいテーマ</translation>
    </message>
</context>
<context>
    <name>ThemeManager</name>
    <message>
        <location filename="../src/theme_manager.cpp" line="78"/>
        <source>Themes</source>
        <translation>テーマ</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="92"/>
        <source>Default</source>
        <translation>デフォルト</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="107"/>
        <source>Gentle Blues</source>
        <translation>Gentle Blues</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="108"/>
        <source>Old School</source>
        <translation>Old School</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="109"/>
        <source>Space Dreams</source>
        <translation>Space Dreams</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="110"/>
        <source>Writing Desk</source>
        <translation>Writing Desk</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="113"/>
        <location filename="../src/theme_manager.cpp" line="174"/>
        <source>New</source>
        <translation>新規</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="117"/>
        <location filename="../src/theme_manager.cpp" line="178"/>
        <source>Duplicate</source>
        <translation>複製</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="131"/>
        <source>Custom</source>
        <translation>カスタム</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="183"/>
        <source>Edit</source>
        <translation>編集</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="188"/>
        <source>Delete</source>
        <translation>削除</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="193"/>
        <source>Import</source>
        <translation>インポート</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="197"/>
        <source>Export</source>
        <translation>エクスポート</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="311"/>
        <source>Question</source>
        <translation>確認</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="311"/>
        <source>Delete theme &apos;%1&apos;?</source>
        <translation>テーマ &apos;%1&apos; を削除しますか？</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="339"/>
        <location filename="../src/theme_manager.cpp" line="416"/>
        <source>Themes (%1)</source>
        <translation>テーマ (%1)</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="339"/>
        <source>Import Theme</source>
        <translation>テーマのインポート</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="416"/>
        <source>Export Theme</source>
        <translation>テーマのエクスポート</translation>
    </message>
</context>
<context>
    <name>Timer</name>
    <message>
        <location filename="../src/timer.cpp" line="255"/>
        <source>&lt;b&gt;%1&lt;/b&gt; - %2</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; - %2</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="340"/>
        <source>Question</source>
        <translation>確認</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="340"/>
        <source>Delete timer?</source>
        <translation>タイマーを削除しますか？</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="355"/>
        <source>&lt;b&gt;Words:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;単語数:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="356"/>
        <source>&lt;b&gt;Pages:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;ページ数:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="357"/>
        <source>&lt;b&gt;Paragraphs:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;段落数:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="358"/>
        <source>&lt;b&gt;Characters:&lt;/b&gt; %L1 / %L2</source>
        <translation>&lt;b&gt;文字数:&lt;/b&gt; %L1 / %L2</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="402"/>
        <source>Set Delay</source>
        <translation>時間で指定</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="403"/>
        <source>Set Time</source>
        <translation>時刻で指定</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="406"/>
        <source>Delay:</source>
        <translation>時間:</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="409"/>
        <source>Time:</source>
        <translation>時刻:</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="418"/>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="431"/>
        <source>Alarm</source>
        <translation>アラーム</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="444"/>
        <source>Type:</source>
        <translation>種類:</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="448"/>
        <source>Memo:</source>
        <translation>メモ:</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="459"/>
        <source>Edit</source>
        <translation>編集</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="461"/>
        <source>Delete</source>
        <translation>削除</translation>
    </message>
</context>
<context>
    <name>TimerDisplay</name>
    <message>
        <location filename="../src/timer_display.cpp" line="150"/>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <location filename="../src/timer_display.cpp" line="160"/>
        <source>No timers running</source>
        <translation>タイマーはありません。</translation>
    </message>
</context>
<context>
    <name>TimerManager</name>
    <message>
        <location filename="../src/timer_manager.cpp" line="46"/>
        <source>Timers</source>
        <translation>タイマー</translation>
    </message>
    <message>
        <location filename="../src/timer_manager.cpp" line="78"/>
        <source>New</source>
        <translation>新規作成</translation>
    </message>
    <message>
        <location filename="../src/timer_manager.cpp" line="83"/>
        <source>Recent</source>
        <translation>履歴</translation>
    </message>
    <message>
        <location filename="../src/timer_manager.cpp" line="123"/>
        <source>Question</source>
        <translation>確認</translation>
    </message>
    <message>
        <location filename="../src/timer_manager.cpp" line="123"/>
        <source>Cancel editing timers?</source>
        <translation>タイマーの編集を中止しますか？</translation>
    </message>
    <message>
        <location filename="../src/timer_manager.cpp" line="316"/>
        <source>+HH:mm:ss</source>
        <translation>+HH:mm:ss</translation>
    </message>
    <message>
        <location filename="../src/timer_manager.cpp" line="323"/>
        <source>%1 - %2</source>
        <translation>%1 - %2</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="../src/window.cpp" line="300"/>
        <source>Loading themes</source>
        <translation>テーマを読み込んでいます</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1146"/>
        <source>Loading sounds</source>
        <translation>音声を読み込んでいます</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="309"/>
        <location filename="../src/window.cpp" line="1065"/>
        <source>Untitled</source>
        <translation>無題</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="682"/>
        <source>Open File</source>
        <translation>開く</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="864"/>
        <source>About FocusWriter</source>
        <translation>FocusWriter について</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="867"/>
        <source>FocusWriter</source>
        <translation>FocusWriter</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="868"/>
        <source>A simple fullscreen word processor</source>
        <translation>A simple fullscreen word processor</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="869"/>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="870"/>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="871"/>
        <source>Uses icons from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; icon theme</source>
        <translation>Uses icons from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; icon theme</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="872"/>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="174"/>
        <location filename="../src/window.cpp" line="928"/>
        <source>Characters: %L1 / %L2</source>
        <translation>文字数: %L1 / %L2</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="172"/>
        <location filename="../src/window.cpp" line="929"/>
        <source>Pages: %L1</source>
        <translation>ページ数: %L1</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="173"/>
        <location filename="../src/window.cpp" line="930"/>
        <source>Paragraphs: %L1</source>
        <translation>段落数: %L1</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="171"/>
        <location filename="../src/window.cpp" line="931"/>
        <source>Words: %L1</source>
        <translation>単語数: %L1</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="602"/>
        <location filename="../src/window.cpp" line="1020"/>
        <source>Opening %1</source>
        <translation>%1 を開いています</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="332"/>
        <source>(Untitled %1)</source>
        <translation>(無題 %1)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="207"/>
        <source>List all documents</source>
        <translation>全文書の表示</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="210"/>
        <source>Switch to Next Document</source>
        <translation>次のドキュメントへ切り替える</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="216"/>
        <source>Switch to Previous Document</source>
        <translation>前のドキュメントへ切り替える</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="222"/>
        <source>Switch to First Document</source>
        <translation>最初のドキュメントへ切り替える</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="228"/>
        <source>Switch to Last Document</source>
        <translation>最後のドキュメントへ切り替える</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="236"/>
        <source>Switch to Document %1</source>
        <translation>%1 へ切り替える</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="296"/>
        <source>Loading settings</source>
        <translation>設定を読み込んでいます</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="318"/>
        <source>Emergency cache is not writable.</source>
        <translation>緊急用のキャッシュに書き込むことができませんでした。</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="338"/>
        <location filename="../src/window.cpp" line="1034"/>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="339"/>
        <source>FocusWriter was not shut down cleanly.</source>
        <translation>FocusWriter は正常に終了できませんでした。</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="340"/>
        <source>Restore from the emergency cache?</source>
        <translation>緊急用のキャッシュから復活させますか？</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="467"/>
        <source>Some files could not be opened.</source>
        <translation>いくつかのファイルが開けませんでした。</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="470"/>
        <source>Some files were opened Read-Only.</source>
        <translation>いくつかをファイルを読み取り専用で開きました。</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1035"/>
        <source>&apos;%1&apos; is newer than the cached copy.</source>
        <translation>&apos;%1&apos; はキャッシュより新しいようです。</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1036"/>
        <source>Overwrite newer file?</source>
        <translation>新しいファイルを上書きしますか？</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1121"/>
        <source>Save Changes?</source>
        <translation>変更を保存しますか？</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1122"/>
        <source>Save changes to the file &apos;%1&apos; before closing?</source>
        <translation>閉じる前にファイル %1 へ加えた変更を保存しますか？</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1123"/>
        <source>Your changes will be lost if you don&apos;t save them.</source>
        <translation>保存しない場合、加えた変更は失われます。</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1153"/>
        <source>Unable to load typewriter sounds.</source>
        <translation>タイプライター音を読み込めませんでした。</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1154"/>
        <source>Please make sure that SDL_mixer is installed.</source>
        <translation>SDL_mixer がインストールされていることを確認してください。</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1290"/>
        <source>&amp;File</source>
        <translation>ファイル (&amp;F)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1291"/>
        <source>&amp;New</source>
        <translation>新規作成 (&amp;N)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1292"/>
        <source>&amp;Open...</source>
        <translation>開く (&amp;O)...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1293"/>
        <source>Reloa&amp;d</source>
        <translation>再読み込み (&amp;D)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1295"/>
        <source>&amp;Save</source>
        <translation>保存 (&amp;S)...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1297"/>
        <source>Save &amp;As...</source>
        <translation>名前を付けて保存 (&amp;A)...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1298"/>
        <source>&amp;Rename...</source>
        <translation>名前の変更 (&amp;R)...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1300"/>
        <source>Save A&amp;ll</source>
        <translation>すべて保存 (&amp;L)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1303"/>
        <source>Manage Sessions</source>
        <translation>セッションの管理</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1305"/>
        <source>New Session</source>
        <translation>新規セッション</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1308"/>
        <source>&amp;Print...</source>
        <translation>印刷 (&amp;P)...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1310"/>
        <source>&amp;Close</source>
        <translation>閉じる (&amp;C)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1311"/>
        <source>&amp;Quit</source>
        <translation>終了 (&amp;Q)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1311"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1315"/>
        <source>&amp;Edit</source>
        <translation>編集 (&amp;E)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1316"/>
        <source>&amp;Undo</source>
        <translation>元に戻す (&amp;U)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1319"/>
        <source>&amp;Redo</source>
        <translation>やり直し (&amp;R)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1323"/>
        <source>Cu&amp;t</source>
        <translation>切り取り (&amp;T)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1326"/>
        <source>&amp;Copy</source>
        <translation>コピー (&amp;C)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1329"/>
        <source>&amp;Paste</source>
        <translation>貼り付け (&amp;P)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1330"/>
        <source>Paste &amp;Unformatted</source>
        <translation>書式を無視して貼り付け</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1330"/>
        <source>Ctrl+Shift+V</source>
        <translation>Ctrl+Shift+V</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1332"/>
        <source>Select &amp;All</source>
        <translation>すべて選択 (&amp;A)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1333"/>
        <source>Select &amp;Scene</source>
        <translation>シーンの選択 (&amp;S)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1333"/>
        <source>Ctrl+Shift+A</source>
        <translation>Ctrl+Shift+A</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1336"/>
        <source>Fo&amp;rmat</source>
        <translation>書式 (&amp;R)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1338"/>
        <source>&amp;Bold</source>
        <translation>太字 (&amp;B)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1340"/>
        <source>&amp;Italic</source>
        <translation>斜体 (&amp;I)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1342"/>
        <source>&amp;Underline</source>
        <translation>下線 (&amp;U)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1344"/>
        <source>Stri&amp;kethrough</source>
        <translation>取り消し線 (&amp;K)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1344"/>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1346"/>
        <source>Sup&amp;erscript</source>
        <translation>下付き文字 (&amp;E)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1346"/>
        <source>Ctrl+^</source>
        <translation>Ctrl+^</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1348"/>
        <source>&amp;Subscript</source>
        <translation>上付き文字 (&amp;S)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1348"/>
        <source>Ctrl+_</source>
        <translation>Ctrl+_</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1352"/>
        <source>Align &amp;Left</source>
        <translation>左揃え (&amp;L)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1352"/>
        <source>Ctrl+{</source>
        <translation>Ctrl+{</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1354"/>
        <source>Align &amp;Center</source>
        <translation>中央揃え (&amp;C)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1354"/>
        <source>Ctrl+|</source>
        <translation>Ctrl+|</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1356"/>
        <source>Align &amp;Right</source>
        <translation>右揃え (&amp;R)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1356"/>
        <source>Ctrl+}</source>
        <translation>Ctrl+}</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1358"/>
        <source>Align &amp;Justify</source>
        <translation>均等割付 (&amp;J)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1358"/>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1368"/>
        <source>&amp;Decrease Indent</source>
        <translation>インデントを減らす (&amp;D)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1368"/>
        <source>Ctrl+&lt;</source>
        <translation>Ctrl+&lt;</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1369"/>
        <source>I&amp;ncrease Indent</source>
        <translation>インデントを増やす (&amp;N)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1369"/>
        <source>Ctrl+&gt;</source>
        <translation>Ctrl+&gt;</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1372"/>
        <source>Le&amp;ft to Right Block</source>
        <translation>左から右へ (&amp;F)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1374"/>
        <source>Ri&amp;ght to Left Block</source>
        <translation>右から左へ (&amp;G)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1382"/>
        <source>&amp;Tools</source>
        <translation>ツール (&amp;T)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1383"/>
        <source>&amp;Find...</source>
        <translation>検索 (&amp;F)...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1384"/>
        <source>Find &amp;Next</source>
        <translation>次を検索 (&amp;N)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1387"/>
        <source>Find Pre&amp;vious</source>
        <translation>前を検索 (&amp;V)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1390"/>
        <source>&amp;Replace...</source>
        <translation>置換 (&amp;R)...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1390"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1392"/>
        <source>Smart &amp;Quotes</source>
        <translation>スマート引用符 (&amp;Q)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1393"/>
        <source>Update &amp;Document</source>
        <translation>文書全体に適用 (&amp;D)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1396"/>
        <source>Update &amp;Selection</source>
        <translation>選択範囲に適用 (&amp;S)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1400"/>
        <source>&amp;Spelling...</source>
        <translation>スペルチェック (&amp;S)...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1400"/>
        <source>F7</source>
        <translation>F7</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1401"/>
        <source>Set &amp;Language...</source>
        <translation>言語の変更 (&amp;S)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1403"/>
        <source>&amp;Timers...</source>
        <translation>タイマー (&amp;T)...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1404"/>
        <source>S&amp;ymbols...</source>
        <translation>シンボル (&amp;Y)...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1405"/>
        <source>&amp;Daily Progress</source>
        <translation>日毎の進捗 (&amp;D)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1408"/>
        <source>&amp;Settings</source>
        <translation>設定 (&amp;S)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1409"/>
        <source>Show &amp;Toolbar</source>
        <translation>ツール バーを表示 (&amp;T)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1414"/>
        <source>Show &amp;Menu Icons</source>
        <translation>メニュー項目のアイコンを表示 (&amp;M)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1420"/>
        <source>F&amp;ocused Text</source>
        <translation>フォーカスされた文字 (&amp;O)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1422"/>
        <source>&amp;Fullscreen</source>
        <translation>全画面表示 (&amp;F)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1422"/>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1424"/>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1428"/>
        <source>M&amp;inimize</source>
        <translation>最小化 (&amp;I)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1428"/>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1430"/>
        <source>&amp;Themes...</source>
        <translation>テーマ (&amp;T)...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1433"/>
        <source>&amp;Preferences...</source>
        <translation>設定 (&amp;P)...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1439"/>
        <source>Focus Off</source>
        <translation>フォーカスの無効</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1441"/>
        <source>Focus One Line</source>
        <translation>一行フォーカス</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1443"/>
        <source>Focus Three Lines</source>
        <translation>三行フォーカス</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1444"/>
        <source>&amp;Paragraph</source>
        <translation>段落 (&amp;P)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1445"/>
        <source>Focus Paragraph</source>
        <translation>段落フォーカス</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1454"/>
        <source>Ctrl+Shift+`</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1459"/>
        <source>&amp;Help</source>
        <translation>ヘルプ (&amp;H)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1432"/>
        <source>Application &amp;Language...</source>
        <translation>Application &amp;Language...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="400"/>
        <source>Some files were unsupported and could not be opened.</source>
        <translation>いくつかのファイルがサポートされていない形式のため開くことができませんでした。</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1438"/>
        <source>&amp;Off</source>
        <translation>オフ (&amp;O)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1440"/>
        <source>One &amp;Line</source>
        <translation>一行 (&amp;L)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1442"/>
        <source>&amp;Three Lines</source>
        <translation>三行 (&amp;T)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1460"/>
        <source>&amp;About</source>
        <translation>FocusWriter について (&amp;A)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1468"/>
        <source>About &amp;Qt</source>
        <translation>Qt について (&amp;Q)</translation>
    </message>
</context>
</TS>
